<?php declare( strict_types=1 );

namespace FernleafSystems\Wordpress\Plugin\Shield\Modules\HackGuard\Render\ScanResults;

use FernleafSystems\Wordpress\Plugin\Shield\Modules\HackGuard\ModCon;
use FernleafSystems\Wordpress\Plugin\Shield\Scans;
use FernleafSystems\Wordpress\Plugin\Shield\Tables\DataTables\Build\Scans\ForMalware;
use FernleafSystems\Wordpress\Services\Services;

class SectionMalware extends SectionBase {

	public function render() :string {
		return $this->getMod()->renderTemplate(
			'/wpadmin_pages/insights/scans/results/section/malware/index.twig',
			$this->buildRenderData()
		);
	}

	protected function buildRenderData() :array {
		$data = $this->buildMalwareData();
		return Services::DataManipulation()
					   ->mergeArraysRecursive( $this->getCommonRenderData(), [
						   'strings' => [
							   'no_files'       => __( "Previous scans didn't detect any files suspected of being malware.", 'wp-simple-firewall' ),
							   'files_found'    => __( "Previous scans detected 1 or more files suspected of being malware.", 'wp-simple-firewall' ),
							   'mal_restricted' => __( 'The Malware File Scanner is only available with ShieldPRO.', 'wp-simple-firewall' ),
						   ],
						   'flags'   => [
							   'mal_is_restricted' => $this->getScanConAFS()->isRestrictedMalwareScan(),
						   ],
						   'vars'    => [
							   'count_items'     => $data[ 'vars' ][ 'count_items' ],
							   'malware'         => $data,
							   'datatables_init' => ( new ForMalware() )
								   ->setMod( $this->getMod() )
								   ->build(),
							   'beacon_help_id'  => 443
						   ]
					   ] );
	}

	private function buildMalwareData() :array {
		/** @var ModCon $mod */
		$mod = $this->getMod();
		$count = $mod->getScansCon()
					 ->getScanResultsCount()
					 ->countMalware();
		$data = [
			'flags' => [
				'has_malware' => $count > 0,
			],
			'vars'  => [
				'count_items' => $count
			]
		];
		$data[ 'flags' ][ 'has_issue' ] = $data[ 'flags' ][ 'has_malware' ];
		return $data;
	}
}